[![PyPI version](https://badge.fury.io/py/x4c.svg)](https://badge.fury.io/py/x4c)
[![PyPI](https://img.shields.io/badge/python-3.11-blue.svg)]()
<!-- [![license](https://img.shields.io/github/license/fzhu2e/x4c.svg)]() -->

# x4c: Xarray for CESM
x4c (xarray4cesm) is an Xarray extension that aims to support efficient and intuitive CESM output analysis and visualization:
- Analysis features: regrid, various of mean calculation, annualization/seasonalization, etc.
- Visualization features: timeseries, horizontal and vertical spatial plots, etc.

> **_Disclaimer:_**  This package is still in its early stage and under active development, and its API could be changed frequently.

## Documentation

+ Homepage: https://fzhu2e.github.io/x4c
+ Installation: https://fzhu2e.github.io/x4c/ug-installation.html


## License
MIT